#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 stack
version:              2.9.3.1
visibility:           public
id:                   stack-2.9.3.1-G2E3Bd0Js6Q137JR8j4riZ
key:                  stack-2.9.3.1-G2E3Bd0Js6Q137JR8j4riZ
license:              BSD-3-Clause
maintainer:           manny@fpcomplete.com
author:               Commercial Haskell SIG
homepage:             http://haskellstack.org
synopsis:             The Haskell Tool Stack
description:
    Please see the documentation at <https://docs.haskellstack.org>
    for usage information.

    If building a '\''stack'\'' executable for distribution, please download the
    source code from <https://github.com/commercialhaskell/stack/releases>
    and build it using Stack itself in order to ensure identical behaviour
    to official binaries.  This package on Hackage is provided for convenience
    and bootstrapping purposes.

    Note that the API for the library is not currently stable, and may
    change significantly, even between minor releases. It is
    currently only intended for use by the executable.

category:             Development
abi:                  2e351930e885f75277df03cae7834f42
exposed:              True
exposed-modules:
    Control.Concurrent.Execute Data.Attoparsec.Args
    Data.Attoparsec.Combinators Data.Attoparsec.Interpreter
    Data.Monoid.Map Network.HTTP.StackClient Options.Applicative.Args
    Options.Applicative.Builder.Extra Options.Applicative.Complicated
    Path.CheckInstall Path.Extra Path.Find Paths_stack Stack.Build
    Stack.Build.Cache Stack.Build.ConstructPlan Stack.Build.Execute
    Stack.Build.Haddock Stack.Build.Installed Stack.Build.Source
    Stack.Build.Target Stack.BuildPlan Stack.Clean Stack.Config
    Stack.Config.Build Stack.Config.Docker Stack.Config.Nix
    Stack.ConfigCmd Stack.Constants Stack.Constants.Config
    Stack.Coverage Stack.DefaultColorWhen Stack.Docker Stack.Dot
    Stack.FileWatch Stack.GhcPkg Stack.Ghci Stack.Ghci.Script
    Stack.Hoogle Stack.IDE Stack.Init Stack.List Stack.Lock Stack.Ls
    Stack.New Stack.Nix Stack.Options.BenchParser
    Stack.Options.BuildMonoidParser Stack.Options.BuildParser
    Stack.Options.CleanParser Stack.Options.Completion
    Stack.Options.ConfigParser Stack.Options.DockerParser
    Stack.Options.DotParser Stack.Options.ExecParser
    Stack.Options.GhcBuildParser Stack.Options.GhcVariantParser
    Stack.Options.GhciParser Stack.Options.GlobalParser
    Stack.Options.HaddockParser Stack.Options.HpcReportParser
    Stack.Options.LogLevelParser Stack.Options.NewParser
    Stack.Options.NixParser Stack.Options.PackageParser
    Stack.Options.ResolverParser Stack.Options.SDistParser
    Stack.Options.ScriptParser Stack.Options.TestParser
    Stack.Options.UploadParser Stack.Options.Utils Stack.Package
    Stack.PackageDump Stack.Path Stack.Prelude Stack.Runners
    Stack.SDist Stack.Script Stack.Setup Stack.Setup.Installed
    Stack.SetupCmd Stack.SourceMap Stack.Storage.Project
    Stack.Storage.User Stack.Storage.Util Stack.Types.Build
    Stack.Types.Compiler Stack.Types.CompilerBuild Stack.Types.Config
    Stack.Types.Config.Build Stack.Types.Docker Stack.Types.GhcPkgId
    Stack.Types.NamedComponent Stack.Types.Nix Stack.Types.Package
    Stack.Types.PackageName Stack.Types.Resolver Stack.Types.SourceMap
    Stack.Types.TemplateName Stack.Types.Version Stack.Unpack
    Stack.Upgrade Stack.Upload System.Info.ShortPathName
    System.Permissions System.Process.Pager System.Terminal

hidden-modules:
    Path.Extended Stack.ComponentFile Stack.PackageFile
    Stack.Types.Cache Stack.Types.Dependency Stack.Types.PackageFile
    Stack.Types.Storage System.Uname

import-dirs:          /usr/lib/ghc-9.6.6/site-local/stack-2.9.3.1
library-dirs:         /usr/lib/ghc-9.6.6/site-local/stack-2.9.3.1
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/stack-2.9.3.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/stack
hs-libraries:         HSstack-2.9.3.1-G2E3Bd0Js6Q137JR8j4riZ
depends:
    Cabal-3.10.3.0 aeson-2.2.2.0-D5UyU4s17IF6uKIJTSur7o
    annotated-wl-pprint-0.7.0-GFWp72SduKx5Zv0YaM2sPQ
    ansi-terminal-1.1-C4C2bxKAKLj8NAa2eKLJr array-0.5.6.0
    async-2.2.6-5xQ7XDEe3v3DeLHeJRStgT
    attoparsec-0.14.4-JfqiEkfNFnE8n0O4G6WZl6 base-4.18.2.1
    base64-bytestring-1.2.1.0-HSSC8ZpQ1EiHU6Qv1r7ZrY
    bytestring-0.11.5.3 casa-client-0.0.3-3NIiUhkgZT27O5YLSI9hvT
    casa-types-0.0.3-AyX1ZtImoRKBigJeeWpqjE
    colour-2.3.7-3naDTtLe7o3I6IP7jsg6LO
    conduit-1.3.6.1-GLye9k05ayiLdzpPDhJU0K
    conduit-extra-1.3.8-C49LxeOQ7VlKv4GFzxOpy7 containers-0.6.7
    crypton-1.0.4-3mMbBQHl0K4EgHAKLusoNW
    crypton-conduit-0.2.3-IZXeB68CEKy4GgnAnUXzPf deepseq-1.4.8.1
    directory-1.3.8.5 echo-0.1.4-BCPf0iNIcqQJp7PonIPBEA
    exceptions-0.10.7 extra-1.7.16-92gEBqN3yIpF5We3DBC4D
    file-embed-0.0.16.0-6A32wX7iXBC7ZTuLWlLLWz
    filelock-0.1.1.8-4iPYRUSvQAe62o1xkiS14i filepath-1.4.300.1
    fsnotify-0.4.4.0-6oOut68MJYx2OAvSr7By0w
    generic-deriving-1.14.7-CXigfkV378cBxew3OS0ZX4
    hackage-security-0.6.3.2-HePyURz6lumGhANqKHyBrw
    hashable-1.4.7.0-4qZi9v5WFMZ3p1WVFpevAr
    hi-file-parser-0.1.8.0-8oUHTb7yINz2TAyYRsO766
    hpack-0.38.0-IJRtnBOwIl1I5DvpwZO1He hpc-0.6.2.0
    http-client-0.7.19-DXRmxPRORBE3MdmQmSy3IG
    http-client-tls-0.3.6.4-HN3tMmJV0pX8jUBu7FQeO5
    http-conduit-2.3.9.1-9jvrxr3X32oD7zCQ7xobvq
    http-download-0.2.1.0-6s7DLYn5D0qLl5V7qi792A
    http-types-0.12.4-JlSzXn1cYaxE3KCJJlxkWV
    memory-0.18.0-6zo36PbRecTK4fqbBnx0f5
    microlens-0.4.14.0-IP2Uuhm3qTnDhkfYobH8B3
    mintty-0.1.4-CFeOovjDLzzJb68ZeM2nF
    mono-traversable-1.0.21.0-53jMJWECRsm2rhqKN28DHE mtl-2.3.1
    mustache-2.4.3.1-NTCkpNyrPK4pzgSPdeChC
    neat-interpolation-0.5.1.4-DHRl6xBk1FtAmdOvEYchp1
    network-uri-2.6.4.2-CsSn6pfoiNDqvqEIqKYSC
    open-browser-0.2.1.1-LxNiN4VEneo8bxQiPfYDai
    optparse-applicative-0.18.1.0-6cREMRvcEOW6x5IeiCw6lt
    pantry-0.8.3-A3v3YiH30QBDf1lN38m4Vh
    path-0.9.6-7SlKGBssG9F9pBBUmPAkp
    path-io-1.8.2-4bRSGLsMN91Bjf2AxNBJqV
    persistent-2.14.6.0-3kQR514rtT0CT79v4LQQXd
    persistent-sqlite-2.13.2.0-FvaK2XbY6lKDDA5Sk4LcDA pretty-1.1.3.6
    primitive-0.9.1.0-60b8JX0ZgoSKEjUEtmG9qp process-1.6.19.0
    project-template-0.2.1.0-EdGFGKZ0Bhh1shlc9l6cX5
    random-1.2.1.3-1S1SEs3xtKIgpnjewCuMr
    retry-0.9.3.1-7lBe6F8shN37VbjsRaRE53
    rio-0.1.24.0-4aw46phB15gDVQLXDSkguI
    rio-prettyprint-0.1.8.0-AhSD7l51kVd84IQg1i2XEk
    split-0.2.5-9bPPlQ4mlHj6gKeWe5Fjp8 stm-2.5.1.0
    streaming-commons-0.2.3.1-55mTgCrUwj06ObLRuCrK5F
    tar-0.6.0.0-Ja6thyYP5xK5bK3lS35iP6 template-haskell-2.20.0.0
    temporary-1.3-HWoowl2obdSCRTCICKYJCV text-2.0.2
    text-metrics-0.3.3-DmVjojWjJokEEJUssChD6S
    th-reify-many-0.1.10-9m1JtBG3XEz8ePPPTZv1Gw time-1.12.2
    tls-2.0.6-9ENg9yRVcD8IszsfKO7Q8r transformers-0.6.1.0
    typed-process-0.2.13.0-J4gP0QEhKut3V3mKs4bIE8
    unicode-transforms-0.4.0.1-qbH0tkhdqf8nFM7hZ4Riq unix-2.8.4.0
    unix-compat-0.7.4.1-1ix4vuxXmr9HJAwOQozvAF
    unliftio-0.2.25.1-8EuOvwMQbnH3C5Rgo2gyOI
    unordered-containers-0.2.20.1-4LGdNZVNGNC9SVCFAuU8Mp
    vector-0.13.2.0-EFjd2WQg5nEG5BmM55CoiV
    yaml-0.11.11.2-JaCnvXVwHr1DIN7Fv30Aj1
    zip-archive-0.4.3.2-ZmLoRzZUGMFRlgbvEMXqr
    zlib-0.7.1.0-o5ZrO8tsYqEMdOctKNx4t

haddock-interfaces:   /usr/share/doc/stack/html/stack.haddock
haddock-html:         /usr/share/doc/stack/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

